@@ -56,9 +56,9 @@ p.value=pf(Ftest,df1,df2,lower.tail = F)
 
 
 if (verbose) {
-            cat("\n", "",METHOD, "\n", 
+            cat("\n", "",METHOD,paste("(alpha = ",alpha,")",sep = ""), "\n", 
                 sep = " ")
-            cat("---------------------------------------------------------", 
+            cat("-------------------------------------------------------------", 
                 "\n", sep = " ")
             cat("  data :", DNAME, "\n\n", sep = " ")
             cat("  statistic  :", Ftest, "\n", sep = " ")
@@ -71,7 +71,7 @@ if (verbose) {
             else {
                 "  Result     : Difference is statistically significant."
             }, "\n")
-            cat("---------------------------------------------------------", 
+            cat("-------------------------------------------------------------", 
                 "\n\n", sep = " ")
         }
 
