@@ -82,9 +82,9 @@ p.value=pf(Ftest,df1,df2,lower.tail = F)
 
 
 if (verbose) {
-            cat("\n", "",METHOD, "\n", 
+            cat("\n", "",METHOD, paste("(alpha = ",alpha,")",sep = ""), "\n", 
                 sep = " ")
-            cat(if (rate!=0){"-----------------------------------------------------------------------------"}else{"---------------------------------------------------------"}, 
+            cat(if (rate!=0){"----------------------------------------------------------------------------------------------"}else{"-------------------------------------------------------------"}, 
                 "\n", sep = " ")
             cat("  data :", DNAME, "\n\n", sep = " ")
             cat("  statistic  :", Ftest, "\n", sep = " ")
@@ -97,7 +97,7 @@ if (verbose) {
             else {
                 "  Result     : Difference is statistically significant."
             }, "\n")
-            cat(if (rate!=0){"-----------------------------------------------------------------------------"}else{"---------------------------------------------------------"}, 
+            cat(if (rate!=0){"----------------------------------------------------------------------------------------------"}else{"-------------------------------------------------------------"}, 
                 "\n", sep = " ")
         }
 
